package org.tinyjee.maven.dim;

import org.apache.maven.plugin.AbstractMojo;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

import java.io.File;

/**
 * Sets the system property "basedir" to the current value of the maven property "basedir".
 * Using this plugin solves an issue with Doxia where macros cannot refer to correct path in multi-module builds.
 * However when builds are run in parallel, this fix is likely to fail.
 *
 * @author juergen_kellerer, 2011-01-27
 * @version 1.0
 * @goal set-basedir
 * @inheritByDefault true
 * @executionStrategy always
 * @phase initialize
 * @execution initialize
 */
public class SetBaseDirPropertyMojo extends AbstractMojo {

	/**
	 * @parameter default-value="${basedir}"
	 * @required
	 */
	private File basedir;

	/**
	 * {@inheritDoc}
	 */
	public void execute() throws MojoExecutionException, MojoFailureException {
		getLog().debug("Setting system property 'basedir' to " + basedir);
		System.setProperty("basedir", basedir.getAbsolutePath());
	}
}
