/*
 * Copyright 2010 - org.tinyjee.maven
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.tinyjee.maven.dim.utils;

import org.tinyjee.maven.dim.RequestParameterTransformer;

import java.util.Map;

import static org.tinyjee.maven.dim.IncludeMacroSignature.PARAM_SOURCE_CLASS;

/**
 * Implements an handler that allows the definition of aliases for request parameters.
 */
public abstract class AbstractAliasHandler implements RequestParameterTransformer {

	final String triggerParameter, targetParameter, sourceClass;

	/**
	 * Constructs a new AbstractAliasHandler for the given values.
	 *
	 * @param triggerParameter the parameter to trigger.
	 * @param targetParameter  the parameter to transfer the trigger value to.
	 * @param sourceClass	  the source class to set if the trigger was present.
	 */
	protected AbstractAliasHandler(String triggerParameter,
								   String targetParameter, String sourceClass) {
		this.triggerParameter = triggerParameter;
		this.targetParameter = targetParameter;
		this.sourceClass = sourceClass;
	}

	/**
	 * {@inheritDoc}
	 */
	public void transformParameters(Map<String, Object> requestParams) {
		Object props = requestParams.get(triggerParameter);
		if (props != null) {
			if (sourceClass != null && !requestParams.containsKey(PARAM_SOURCE_CLASS))
				requestParams.put(PARAM_SOURCE_CLASS, sourceClass);
			requestParams.put(targetParameter, props);
		}
	}
}
