/*
 * Copyright 2010 - org.tinyjee.maven
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.tinyjee.maven.dim.utils;

import org.apache.maven.doxia.logging.Log;
import org.apache.maven.doxia.logging.SystemStreamLog;

/**
 * Allows access to the log subsystem by arbitrary classes.
 *
 * @author Juergen_Kellerer, 2010-09-07
 * @version 1.0
 */
public final class MacroLoggers extends ThreadLocal<Log> {

	public static final MacroLoggers INSTANCE = new MacroLoggers();

	/**
	 * Returns the current, thread bound logger.
	 *
	 * @return the current, thread bound logger.
	 */
	public static Log getLogger() {
		return INSTANCE.get();
	}

	/**
	 * Returns the singleton instance of MacroLoggers.
	 *
	 * @return the singleton instance of MacroLoggers.
	 */
	public static MacroLoggers getInstance() {
		return INSTANCE;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	protected Log initialValue() {
		return new SystemStreamLog();
	}

	private MacroLoggers() {
	}
}
